![Python package](https://github.com/fingafrog/fingafrog/workflows/Python%20package/badge.svg)

# About Me
Hi! I'm a python package. Install me with `pip install fingafrog`. Talk to me at the command line by running `fingafrog`. 

# About My Owner
Chris started the [andromia github organization](https://github.com/andromia) to push industry-bridging ideas into the open-sourced world. Please check it out!